@@ -34,20 +34,26 @@ def get_ruuvi_data():
     # get_data_for_sensors will look data for the duration of timeout_in_sec
 
     ruuvi_tags = {}
-
+    logging.info("Getting data for sensors")
     for ruuvi in SETTINGS["ruuvitags"]:
         ruuvi_tags[ruuvi["MAC"]] = ruuvi
 
+    logging.info("Getting data for sensors " + str(ruuvi_tags))
+
     ruuvi_data = RuuviTagSensor.get_data_for_sensors([m for m in ruuvi_tags], TIMEOUT)
 
+    logging.info("Got data for sensors " + str(ruuvi_data))
+
     # Append the name of the sensor to the data
     for ruuvi_data_point in ruuvi_data:
-        ruuvi_data_point["name"] = ruuvi_tags[ruuvi_data_point]["name"]
-
-    # Compensate temperature offset
-    for ruuvi_data_point in ruuvi_data:
-        ruuvi_data_point["temperature_calibrated"] = ruuvi_data_point["temperature"] + ruuvi_tags[ruuvi_data_point["mac"]]["temperatureOffset"]
+        logging.info("Apending name for " + ruuvi_data_point)
+        ruuvi_data[ruuvi_data_point]["name"] = ruuvi_tags[ruuvi_data_point]["name"]
+        ruuvi_data[ruuvi_data_point]["temperature_calibrated"] = (
+            ruuvi_data_point["temperature"]
+            + ruuvi_tags[ruuvi_data_point["mac"]]["temperatureOffset"]
+        )
 
+    logging.info("Writing data to database")
     # Store in sqlite
     conn = sqlite3.connect("dbdata/temperature.sqlite")
     c = conn.cursor()
@@ -69,6 +75,7 @@ def get_ruuvi_data():
         conn.commit()
     conn.close()
 
+    logging.info("Returning data")
     return ruuvi_data
 
 
@@ -102,7 +109,14 @@ async def full(update: Update, context: ContextTypes.DEFAULT_TYPE):
         text = to_json(datas)
 
     except Exception as e:
-        text = "Ei saatu dataa. Exception: " + str(e) + " " + str(type(e))
+        import traceback
+
+        text = (
+            "Ei saatu dataa. Exception: "
+            + str(e)
+            + " "
+            + str(type(e) + ", " + str(traceback.format_exc()))
+        )
         logging.error(e)
 
     await context.bot.send_message(chat_id=update.effective_chat.id, text=text)
@@ -110,18 +124,12 @@ async def full(update: Update, context: ContextTypes.DEFAULT_TYPE):
 
 async def temperature(update: Update, context: ContextTypes.DEFAULT_TYPE):
 
-    try:
-        datas = get_ruuvi_data()
-
-        # Get only temperature from data
-        for mac in datas:
-            datas[mac] = datas[mac]["temperature"]
-
-        text = to_json(datas)
-
-    except Exception as e:
-        text = "Ei saatu dataa. Exception: " + str(e) + " " + str(type(e))
-        logging.error(e)
+    # Get the data from sqlite database
+    conn = sqlite3.connect("dbdata/temperature.sqlite")
+    c = conn.cursor()
+    c.execute("SELECT * FROM ruuvi ORDER BY datetime DESC LIMIT 1")
+    data = c.fetchone()
+    text = " ".join(map(str, data))
 
     await context.bot.send_message(chat_id=update.effective_chat.id, text=text)
 
@@ -232,7 +240,6 @@ async def unset(update: Update, context: ContextTypes.DEFAULT_TYPE) -> None:
 
 
 def main():
-    global MACS
     global SETTINGS
     global ACTIVE_ALARMS
 
